import * as _backstage_backend_plugin_api from '@backstage/backend-plugin-api';
import { AuthService, LoggerService, SchedulerServiceTaskRunner, SchedulerService } from '@backstage/backend-plugin-api';
import { Config } from '@backstage/config';
import { Events } from '@backstage/plugin-bitbucket-cloud-common';
import { EntityProvider, CatalogService, EntityProviderConnection } from '@backstage/plugin-catalog-node';
import { EventsService } from '@backstage/plugin-events-node';

/**
 * @public
 */
declare const catalogModuleBitbucketCloudEntityProvider: _backstage_backend_plugin_api.BackendFeature;

/**
 * Discovers catalog files located in [Bitbucket Cloud](https://bitbucket.org).
 * The provider will search your Bitbucket Cloud account and register catalog files matching the configured path
 * as Location entity and via following processing steps add all contained catalog entities.
 * This can be useful as an alternative to static locations or manually adding things to the catalog.
 *
 * @public
 */
declare class BitbucketCloudEntityProvider implements EntityProvider {
    private readonly auth;
    private readonly catalog;
    private readonly client;
    private readonly config;
    private readonly events;
    private readonly logger;
    private readonly scheduleFn;
    private connection?;
    static fromConfig(config: Config, options: {
        auth: AuthService;
        catalog: CatalogService;
        events: EventsService;
        logger: LoggerService;
        schedule?: SchedulerServiceTaskRunner;
        scheduler?: SchedulerService;
    }): BitbucketCloudEntityProvider[];
    private constructor();
    private createScheduleFn;
    /** {@inheritdoc @backstage/plugin-catalog-node#EntityProvider.getProviderName} */
    getProviderName(): string;
    /** {@inheritdoc @backstage/plugin-catalog-node#EntityProvider.getTaskId} */
    getTaskId(): string;
    /** {@inheritdoc @backstage/plugin-catalog-node#EntityProvider.connect} */
    connect(connection: EntityProviderConnection): Promise<void>;
    refresh(logger: LoggerService): Promise<void>;
    private enhanceEvent;
    private shouldProcessEvent;
    onRepoPush(event: Events.RepoPushEvent): Promise<void>;
    private onRepoUpdated;
    private updateForChanges;
    private findExistingLocations;
    private findCatalogFiles;
    private processQuery;
    private matchesFilters;
    private toDeferredEntities;
    private static toUrl;
    private static toLocationSpec;
}

export { BitbucketCloudEntityProvider, catalogModuleBitbucketCloudEntityProvider as default };
